Capability enum

Represents the hardware and software capabilities of the device regarding WiFi RTT.

Inheritance
Available extensions

Values

wifiRtt → const Capability

Indicates if the device hardware supports WiFi RTT (Round-Trip-Time).

wifi80211az → const Capability

Indicates if the device supports 802.11az Non-Trigger Based (NTB) ranging.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Capability>
A constant List of the values in this enum, in order of their declaration.