APScanResult class
Represents a WiFi access point found during a scan.
Constructors
-
APScanResult({required String ssid, required String bssid, required int level, required int frequency, required int timestamp, required bool is80211mcResponder, required bool is80211azResponder, required List<
String> capabilities}) - APScanResult.fromMap(Map map)
-
Creates an APScanResult from a map received via the platform channel.
factory
Properties
- bssid → String
-
The hardware address (Basic Service Set Identifier).
final
-
capabilities
→ List<
String> -
The list of capabilities (e.g.,
WPA2-PSK-CCMP,ESS).final - frequency → int
-
The center frequency of the primary 20 MHz channel (in MHz).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- is80211azResponder → bool
-
Indicates if the AP supports 802.11az (Next Gen Positioning).
final
- is80211mcResponder → bool
-
Indicates if the AP supports 802.11mc (Fine Timing Measurement).
final
- level → int
-
The detected signal level in dBm, also known as the RSSI.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ssid → String
-
The network name (Service Set Identifier).
final
- timestamp → int
-
The timestamp in microseconds indicating when the result was last seen.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited