FtmCapabilities class
Represents the full capability profile of the device.
Constructors
-
FtmCapabilities({required Map<
Capability, bool> status, required bool permissionsGranted, required int androidVersion})
Properties
- androidVersion → int
-
The Android SDK version of the device.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isWifi80211azSupported → bool
-
Convenience getter for 802.11az support.
no setter
- isWifiRttSupported → bool
-
Convenience getter for WiFi RTT support.
no setter
- permissionsGranted → bool
-
Whether the necessary runtime permissions are currently granted.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
status
→ Map<
Capability, bool> -
A map of hardware-specific Capability supports.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited